<?php
namespace KnitPay\Gateways\PayUmoney;

use Pronamic\WordPress\Pay\Core\XML\Security;
use stdClass;
use Exception;
use WP_Error;

/**
 * Title: PayUmoney Client
 * Copyright: 2020 Knit Pay
 *
 * @author Knit Pay
 * @version 1.9.1
 * @since 1.0.0
 */
class Client {

	const LIVE_URL = 'https://secure.payu.in';

	const TEST_URL = 'https://sandboxsecure.payu.in';

	const BOLT_LIVE_URL = 'https://checkout-static.citruspay.com/bolt/run/bolt.min.js';

	const BOLT_TEST_URL = 'https://sboxcheckout-static.citruspay.com/bolt/run/bolt.min.js';

	const CHECKOUT_REDIRECT_MODE = 0;

	const CHECKOUT_BOLT_MODE = 1;

	const CHECKOUT_URL_MODE = 2;


	/**
	 * merchant_key.
	 *
	 * @var string
	 */
	private $merchant_key;

	private $merchant_salt;

	private $mode;

	private $payment_server_url;

	private $bolt_url;

	/**
	 * Construct and initialize an PayUmoney Client
	 *
	 * @param Config $config
	 */
	public function __construct( Config $config ) {
		$this->payment_server_url = self::LIVE_URL;
		$this->bolt_url           = self::BOLT_LIVE_URL;
		$this->merchant_key       = $config->merchant_key;
		$this->merchant_salt      = $config->merchant_salt;
		$this->mode               = $config->mode;
	}

	public function get_action_url( $data ) {
		$response = wp_remote_post(
			$this->payment_server_url . '/_payment',
			array(
				'body'        => $data,
				'redirection' => 0,
			)
		);

		if ( $response instanceof WP_Error ) {
			throw new Exception( 'Something went wrong. Please try again later.' );
		}

		if ( ! $response['headers']->offsetExists( 'location' ) ) {
			throw new Exception( 'Payment link could not be generated. Kindly check the API keys and try again.' );
		}
		return $response['headers']->offsetGet( 'location' );
	}

	/**
	 * Set the payment server URL
	 *
	 * @param string $url
	 *            an URL
	 */
	public function set_payment_server_url( $url ) {
		$this->payment_server_url = $url;
	}

	public function get_payment_server_url() {
		return $this->payment_server_url;
	}

	public function set_bolt_url( $url ) {
		$this->bolt_url = $url;
	}

	public function get_bolt_url() {
		return $this->bolt_url;
	}
}
